import{M as a}from"./Modal.4485a18b.js";import{d as r,v as d,r as _,a as c,b as f,c as l,e as n,w as i,F as m,x as u,q as p}from"./registerWidgets.cecc7add.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0e7187d6-9fbf-474a-abf5-a5402301670f",e._sentryDebugIdIdentifier="sentry-dbid-0e7187d6-9fbf-474a-abf5-a5402301670f")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=_(null);return(g,v)=>{const s=c("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-7e290e34"]]);export{I as default};
//# sourceMappingURL=Home.e9276311.js.map
