import{_ as k}from"./logo.084e5d7c.js";import{q as i,b as o,c as t,O as u,Q as p,x as a,d as b,H as I,a as $,z as _,N as f,e as r,w as g,U as m,F as w,L,D as x,aq as N}from"./registerWidgets.cecc7add.js";import{p as l}from"./passwordlessManager.8b0c672e.js";import{a as C}from"./asyncComputed.08fdcc30.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="d9e661f1-55ad-4901-9d4c-bf2beedfc8a4",e._sentryDebugIdIdentifier="sentry-dbid-d9e661f1-55ad-4901-9d4c-bf2beedfc8a4")}catch{}})();const B={},v=e=>(u("data-v-439be421"),e=e(),p(),e),D={class:"logo"},S=v(()=>a("img",{class:"logo-img",src:k,alt:"Abstra cloud logo"},null,-1)),V=v(()=>a("span",null,"Abstra Cloud",-1)),U=[S,V];function q(e,s){return o(),t("div",D,U)}const A=i(B,[["render",q],["__scopeId","data-v-439be421"]]),E={key:0},F={key:1,class:"logged"},R={class:"author-email"},z={key:2},H=b({__name:"LoginBlock",setup(e){const s=I(),{result:n,loading:c,refetch:d}=C(async()=>l.getUser());function h(){l.removeUser(),d(),s.push({name:"login"})}return(P,W)=>{const y=$("router-link");return _(c)?(o(),t("div",E,"loading...")):_(n)?(o(),t("div",F,[a("span",R,f(_(n).claims.email),1),a("button",{class:"btn",onClick:h},"Logout")])):(o(),t("div",z,[r(y,{class:"btn",to:"/login"},{default:g(()=>[m("Login")]),_:1})]))}}});const M=i(H,[["__scopeId","data-v-6c08207b"]]),O=e=>(u("data-v-7bfa390c"),e=e(),p(),e),Q={class:"nav"},T={class:"left"},j={key:0,class:"breadcrumb-container"},G=O(()=>a("span",{class:"divider"},">",-1)),J={class:"right"},K=b({__name:"Navbar",props:{breadcrumb:{}},setup(e){return(s,n)=>(o(),t("nav",Q,[a("div",T,[r(A),s.breadcrumb?(o(),t("div",j,[(o(!0),t(w,null,L(s.breadcrumb,(c,d)=>(o(),t("span",{key:d,class:"breadcrumb-item"},[r(_(N),{class:"breadcrumb-link",to:c.path},{default:g(()=>[m(f(c.label),1)]),_:2},1032,["to"]),G]))),128))])):x("",!0)]),a("div",J,[r(M)])]))}});const se=i(K,[["__scopeId","data-v-7bfa390c"]]);export{se as N};
//# sourceMappingURL=Navbar.0a04bae4.js.map
