import{u as s}from"./icons.a47594f6.js";import{d as r,a as c,b as i,c as d,e as _,z as l,U as u,q as f}from"./registerWidgets.cecc7add.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="40a314db-0785-4279-8957-abcfa632b074",e._sentryDebugIdIdentifier="sentry-dbid-40a314db-0785-4279-8957-abcfa632b074")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.5be26fba.js.map
