import{d,r as l,o as u,a6 as c,b as f,c as p,N as y,af as m}from"./registerWidgets.cecc7add.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="6e90ee03-8ac4-4286-893d-73a201823738",e._sentryDebugIdIdentifier="sentry-dbid-6e90ee03-8ac4-4286-893d-73a201823738")}catch{}})();const g=d({__name:"ActionButton",props:{action:{}},emits:["next"],setup(e,{emit:n}){const o=e,s=l(null);u(()=>{s.value&&o.action.setElement(s.value),c.addAction(o.action)});const a=()=>n("next");return(r,t)=>(f(),p("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>a()),onKeydown:t[1]||(t[1]=m(i=>a(),["enter"]))},y(r.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.bfc19705.js.map
