import{d as m,H as y,K as _,b as g,t as J,z as h}from"./registerWidgets.cecc7add.js";import{e as k,f as w,g as C}from"./icons.a47594f6.js";import{a as I}from"./asyncComputed.08fdcc30.js";import{J as d}from"./jobs.ca343ddb.js";import{R as v}from"./RuntimeList.27942af1.js";import"./activeRecord.2a9ab687.js";import"./pubsub.a43e35aa.js";import"./DropdownMenu.4df8c96d.js";import"./CircularLoading.45f7b299.js";import"./lottie.79ce2fdf.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[i]="ea9b8bd7-7fb5-4380-8d63-986cb87a6207",n._sentryDebugIdIdentifier="sentry-dbid-ea9b8bd7-7fb5-4380-8d63-986cb87a6207")}catch{}})();const $=m({__name:"Jobs",setup(n){const i=y(),{loading:r,result:a,refetch:c}=I(()=>d.list()),l=({key:e})=>i.push({path:`/_editor/job/${encodeURIComponent(e)}`}),u=async({key:e})=>{var o,t;await((t=(o=a.value)==null?void 0:o.find(s=>s.identifier===e))==null?void 0:t.duplicate()),c()},b=async()=>{const e=await d.create();l({key:e.identifier})},f=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this job?")&&(await((t=(o=a.value)==null?void 0:o.find(s=>s.identifier===e))==null?void 0:t.delete()),c())},p=_(()=>{var e,o;return{columns:[{name:"Job Name"},{name:"Path"},{name:"Job Actions"}],rows:(o=(e=a.value)==null?void 0:e.map(t=>({key:t.identifier,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/job/${encodeURIComponent(t.identifier)}`},{text:t.identifier},{text:"",classes:["centered"],actions:[{icon:k,label:"Delete",onClick:f,dangerous:!0},{icon:w,label:"Edit Job",onClick:l},{icon:C,label:"Duplicate",onClick:u}]}]})))!=null?o:[]}});return(e,o)=>(g(),J(v,{loading:h(r),title:"Python Jobs",description:"Schedule Python scripts like events on a calendar","create-button-text":"Create Job","empty-title":"No jobs here yet",table:p.value,onCreate:b},null,8,["loading","table"]))}});export{$ as default};
//# sourceMappingURL=Jobs.e0cf9675.js.map
