import{d as k,H as y,K as h,b,t as g,z as _}from"./registerWidgets.cecc7add.js";import{e as H,f as w,g as C}from"./icons.a47594f6.js";import{a as I}from"./asyncComputed.08fdcc30.js";import{H as d}from"./hooks.f8fb2fa8.js";import{R as x}from"./RuntimeList.27942af1.js";import"./activeRecord.2a9ab687.js";import"./pubsub.a43e35aa.js";import"./DropdownMenu.4df8c96d.js";import"./CircularLoading.45f7b299.js";import"./lottie.79ce2fdf.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="1397c431-051d-48d3-9ac6-3db6daacfb82",a._sentryDebugIdIdentifier="sentry-dbid-1397c431-051d-48d3-9ac6-3db6daacfb82")}catch{}})();const $=k({__name:"Hooks",setup(a){const n=y(),{loading:r,result:s,refetch:c}=I(()=>d.list()),l=({key:e})=>n.push({path:`/_editor/hook/${encodeURIComponent(e)}`}),u=async({key:e})=>{var o,t;await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),c()},p=async()=>{const e=await d.create();l({key:e.path})},m=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this hook?")&&(await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),c())},f=h(()=>{var e,o;return{columns:[{name:"Hook Name"},{name:"Path"},{name:"Hook Actions"}],rows:(o=(e=s.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/hook/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",classes:["centered"],actions:[{icon:H,label:"Delete",onClick:m,dangerous:!0},{icon:w,label:"Edit Hook",onClick:l},{icon:C,label:"Duplicate",onClick:u}]}]})))!=null?o:[]}});return(e,o)=>(b(),g(x,{loading:_(r),title:"Python Hooks",description:"Trigger your Python scripts with a request.","create-button-text":"Create Hook","empty-title":"No hooks here yet",table:f.value,onCreate:p},null,8,["loading","table"]))}});export{$ as default};
//# sourceMappingURL=Hooks.ea666fc7.js.map
