import{d as p,J as u,K as m,b,t as f,w as _,z as y,O as g,Q as w,x as i,U as n,q as h}from"./registerWidgets.cecc7add.js";import{a as x}from"./asyncComputed.08fdcc30.js";import"./gateway.c00982e9.js";import{B as I}from"./build.4de1efb7.js";import"./index.d9da78e8.js";import{C as v}from"./CrudView.48449181.js";import{J as B,L as D}from"./icons.a47594f6.js";import{r as C}from"./console.54ea9d21.js";import{f as k}from"./index.b048d0fb.js";import"./passwordlessManager.8b0c672e.js";import"./pubsub.a43e35aa.js";import"./activeRecord.2a9ab687.js";import"./DropdownMenu.4df8c96d.js";import"./Modal.4485a18b.js";import"./LoadingIndicator.06d4594a.js";import"./lottie.79ce2fdf.js";import"./index.a0dcefc8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b517a198-4b01-4a3d-8e8b-049b9dbb9521",e._sentryDebugIdIdentifier="sentry-dbid-b517a198-4b01-4a3d-8e8b-049b9dbb9521")}catch{}})();const S=e=>(g("data-v-e61ab2b9"),e=e(),w(),e),V=S(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),j=p({__name:"Builds",setup(e){const a=u().params.projectId,{loading:d,result:l}=x(()=>I.list(a)),c=m(()=>{var s,r;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(r=(s=l.value)==null?void 0:s.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8),classes:["centered"]},{text:k(t.createdAt,Date.now(),{addSuffix:!0}),classes:[]},{text:t.status+(t.log?": "+t.log:""),classes:[]},{text:"",classes:["centered"],actions:[{icon:B,label:"View logs",onClick:()=>C.push({name:"logs",params:{projectId:a},query:{buildId:t.id}})},{icon:D,label:"Download files",onClick:()=>t.download()}]}]})))!=null?r:[]}});return(s,r)=>(b(),f(v,{"entity-name":"build",loading:y(d),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:c.value},{"empty-description":_(()=>[V]),_:1},8,["loading","table"]))}});const F=h(j,[["__scopeId","data-v-e61ab2b9"]]);export{F as default};
//# sourceMappingURL=Builds.005477df.js.map
