import{S as c}from"./Sidebar.cce5183a.js";import{N as d}from"./Navbar.0a04bae4.js";import{C as m,D as p,E as l}from"./icons.a47594f6.js";import{d as u,J as _,K as b,a as f,b as g,c as v,e as t,x as y,F as z,q as h}from"./registerWidgets.cecc7add.js";import{a as w}from"./asyncComputed.08fdcc30.js";import"./gateway.c00982e9.js";import{O as I}from"./organization.152bdd94.js";import"./index.d9da78e8.js";import"./Tooltip.44f3c0f6.js";import"./logo.084e5d7c.js";import"./passwordlessManager.8b0c672e.js";import"./pubsub.a43e35aa.js";import"./activeRecord.2a9ab687.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cfbb8012-1fa3-440c-86e4-ae6dd7f50105",e._sentryDebugIdIdentifier="sentry-dbid-cfbb8012-1fa3-440c-86e4-ae6dd7f50105")}catch{}})();const O={class:"organization"},x=u({__name:"Organization",setup(e){const n=_().params.organizationId,{result:o}=w(()=>I.get(n)),r=b(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:m,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(D,k)=>{const s=f("router-view");return g(),v(z,null,[t(d,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const R=h(x,[["__scopeId","data-v-51ce7239"]]);export{R as default};
//# sourceMappingURL=Organization.d9e92bac.js.map
