import{L as c}from"./lottie.79ce2fdf.js";import{d as l,r as u,o as f,K as r,b as p,c as _,x as y,A as s,B as g,q as b}from"./registerWidgets.cecc7add.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b8e50fab-3aed-4f97-aa10-a2f521bc0fe4",e._sentryDebugIdIdentifier="sentry-dbid-b8e50fab-3aed-4f97-aa10-a2f521bc0fe4")}catch{}})();const v=l({__name:"CircularLoading",props:{direction:{},justify:{},size:{}},setup(e){const n=e,a=u(null);f(()=>{!a.value||c.loadAnimation({container:a.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})});const i=r(()=>{const{direction:t="row",justify:o="space-between"}=n;return{flexDirection:t,justifyContent:o}}),d=r(()=>{const{size:t="40"}=n;return{width:`${t}px`,height:`${t}px`}});return(t,o)=>(p(),_("div",{class:"container",style:s(i.value)},[y("div",{ref_key:"loading",ref:a,style:s(d.value)},null,4),g(t.$slots,"default",{},void 0,!0)],4))}});const x=b(v,[["__scopeId","data-v-a1f994d4"]]);export{x as L};
//# sourceMappingURL=CircularLoading.45f7b299.js.map
