import{q as o,a as r,b as i,t as c,f as d,g as p,_,h as f,k as u,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.cecc7add.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9bf2fdba-1fa6-4f2d-8f36-69377bea4dac",e._sentryDebugIdIdentifier="sentry-dbid-9bf2fdba-1fa6-4f2d-8f36-69377bea4dac")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.bd4c3ab0.js"),["assets/Player.bd4c3ab0.js","assets/index.a0dcefc8.js","assets/registerWidgets.cecc7add.js","assets/registerWidgets.11938843.css","assets/uuid.dbda6006.js","assets/broker.352d6f95.js","assets/passwordlessManager.8b0c672e.js","assets/pubsub.a43e35aa.js","assets/Passwordless.0943eeec.js","assets/CircularLoading.45f7b299.js","assets/lottie.79ce2fdf.js","assets/CircularLoading.f81b57b4.css","assets/icons.a47594f6.js","assets/Passwordless.86ac0c56.css","assets/executeJs.5aff51e5.js","assets/PlayerNavbar.208ad882.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.5d7ea3ec.js","assets/Steps.998aa76d.css","assets/Modal.4485a18b.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.bbded71d.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.bfc19705.js","assets/broker.1ce8d5ac.css","assets/DashPlayer.a348af79.js","assets/runnerData.fab8bd8b.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.08fdcc30.js","assets/Player.8f362335.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=f({render:()=>u(x)});l.init(),D.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.91660627.js.map
