import{P as r}from"./Passwordless.0943eeec.js";import{d as a,H as i,b as d,c as _,e as s,w as c,q as m}from"./registerWidgets.cecc7add.js";import{M as p}from"./member.dedd26d1.js";import{W as f}from"./WidgetsFrame.bbded71d.js";import"./CircularLoading.45f7b299.js";import"./lottie.79ce2fdf.js";import"./icons.a47594f6.js";import"./passwordlessManager.8b0c672e.js";import"./pubsub.a43e35aa.js";import"./gateway.c00982e9.js";import"./activeRecord.2a9ab687.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="398727a4-d137-434a-9417-2457f2219902",e._sentryDebugIdIdentifier="sentry-dbid-398727a4-d137-434a-9417-2457f2219902")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=i();async function t(n){await p.login(),o.push({name:"home"})}return(n,g)=>(d(),_("div",l,[s(f,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:c(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=m(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.23e038e7.js.map
